.preloader-circle,
.preloader-circle div {
    box-sizing: border-box;
}
.preloader-circle {
    display: inline-block;
    transform: translateZ(1px);
}
.preloader-circle > div {
    display: inline-block;
    width: 64px;
    height: 64px;
    margin: 8px;
    background: currentColor;
    border-radius: 50%;
    animation: preloader-circle 2.4s cubic-bezier(0, 0.2, 0.8, 1) infinite;
}

@keyframes preloader-circle {
    0%, 100% {
        animation-timing-function: cubic-bezier(0.5, 0, 1, 0.5);
    }
    0% {
        transform: rotateY(0deg);
    }
    50% {
        transform: rotateY(1800deg);
        animation-timing-function: cubic-bezier(0, 0.5, 0.5, 1);
    }
    100% {
        transform: rotateY(3600deg);
    }
}