.preloader-ellipsis {
    display: inline-block;
    position: relative;
    width: 80px;
    height: 80px;
  }
.preloader-ellipsis div {
    position: absolute;
    top: 33px;
    width: 13px;
    height: 13px;
    border-radius: 50%;
    background: #fff;
    animation-timing-function: cubic-bezier(0, 1, 1, 0);
}
.preloader-ellipsis div:nth-child(1) {
    left: 8px;
    animation: preloader-ellipsis1 0.6s infinite;
}
.preloader-ellipsis div:nth-child(2) {
    left: 8px;
    animation: preloader-ellipsis2 0.6s infinite;
}
.preloader-ellipsis div:nth-child(3) {
    left: 32px;
    animation: preloader-ellipsis2 0.6s infinite;
}
.preloader-ellipsis div:nth-child(4) {
    left: 56px;
    animation: preloader-ellipsis3 0.6s infinite;
}

@keyframes preloader-ellipsis1 {
    0% {
        transform: scale(0);
    }
    100% {
        transform: scale(1);
    }
}

@keyframes preloader-ellipsis3 {
    0% {
        transform: scale(1);
    }
    100% {
        transform: scale(0);
    }
}

@keyframes preloader-ellipsis2 {
    0% {
        transform: translate(0, 0);
    }
    100% {
        transform: translate(24px, 0);
    }
}
